@@ -4,10 +4,11 @@ import astropy.units as u
 import astropy.wcs
 from astropy.coordinates import SkyCoord
 
+from sunpy import log
 from sunpy.coordinates import frames, sun
 from sunpy.util import MetaDict
 
-__all__ = ['meta_keywords', 'make_fitswcs_header', 'get_observer_meta']
+__all__ = ['meta_keywords', 'make_fitswcs_header', 'get_observer_meta', 'make_heliographic_header']
 
 
 def meta_keywords():
@@ -27,7 +28,8 @@ def meta_keywords():
 
 
 @u.quantity_input(equivalencies=u.spectral())
-def make_fitswcs_header(data, coordinate,
+def make_fitswcs_header(data,
+                        coordinate,
                         reference_pixel: u.pix = None,
                         scale: u.arcsec/u.pix = None,
                         rotation_angle: u.deg = None,
@@ -37,7 +39,8 @@ def make_fitswcs_header(data, coordinate,
                         observatory=None,
                         wavelength: u.angstrom = None,
                         exposure: u.s = None,
-                        projection_code="TAN"):
+                        projection_code="TAN",
+                        unit=None):
     """
     Function to create a FITS-WCS header from a coordinate object
     (`~astropy.coordinates.SkyCoord`) that is required to
@@ -45,7 +48,7 @@ def make_fitswcs_header(data, coordinate,
 
     Parameters
     ----------
-    data : `~numpy.ndarray` or `tuple`
+    data : `~numpy.ndarray`, `~astropy.units.Quantity`, or `tuple`
         Array data of Map for which a header is required, or the shape of the
         data array (in numpy order, i.e. ``(y_size, x_size)``).
     coordinate : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseCoordinateFrame`
@@ -81,6 +84,10 @@ def make_fitswcs_header(data, coordinate,
         Exposure time of the observation
     projection_code : `str`, optional
         The FITS standard projection code for the new header.
+    unit : `~astropy.units.Unit`, optional
+        Units of the array data of the Map. This will populate the the ``'bunit'`` meta keyword.
+        If ``data`` is a `~astropy.units.Quantity`, the unit specified here will take precedence
+        over the unit information attached to ``data``.
 
     Returns
     -------
@@ -113,9 +120,15 @@ def make_fitswcs_header(data, coordinate,
     else:
         shape = data
 
+    if hasattr(data, "unit"):
+        if unit is None:
+            unit = data.unit
+        else:
+            log.info("Overwriting data's current unit with specified unit.")
+
     meta_wcs = _get_wcs_meta(coordinate, projection_code)
 
-    meta_wcs = _set_instrument_meta(meta_wcs, instrument, telescope, observatory, wavelength, exposure)
+    meta_wcs = _set_instrument_meta(meta_wcs, instrument, telescope, observatory, wavelength, exposure, unit)
     meta_wcs = _set_transform_params(meta_wcs, coordinate, reference_pixel, scale, shape)
     meta_wcs = _set_rotation_params(meta_wcs, rotation_angle, rotation_matrix)
 
@@ -153,7 +166,7 @@ def _set_rotation_params(meta_wcs, rotation_angle, rotation_matrix):
         rotation_angle = 0 * u.deg
 
     if rotation_angle is not None:
-        lam = meta_wcs['cdelt2'] / meta_wcs['cdelt1']
+        lam = meta_wcs['cdelt1'] / meta_wcs['cdelt2']
         p = np.deg2rad(rotation_angle)
 
         rotation_matrix = np.array([[np.cos(p), -1 * lam * np.sin(p)],
@@ -262,7 +275,7 @@ def get_observer_meta(observer, rsun: (u.Mm, None) = None):
     return coord_meta
 
 
-def _set_instrument_meta(meta_wcs, instrument, telescope, observatory, wavelength, exposure):
+def _set_instrument_meta(meta_wcs, instrument, telescope, observatory, wavelength, exposure, unit):
     """
     Function to correctly name keywords from keyword arguments
     """
@@ -277,6 +290,8 @@ def _set_instrument_meta(meta_wcs, instrument, telescope, observatory, wavelengt
         meta_wcs['waveunit'] = wavelength.unit.to_string("fits")
     if exposure is not None:
         meta_wcs['exptime'] = exposure.to_value(u.s)
+    if unit is not None:
+        meta_wcs['bunit'] = unit.to_string("fits")
 
     return meta_wcs
 
@@ -361,3 +376,77 @@ _map_meta_keywords = {
     'CD2_2':
     'Matrix element CDi_j describing the rotation required to align solar North with the top of the image.'
 }
+
+
+def make_heliographic_header(date, observer_coordinate, shape, *, frame, projection_code="CAR"):
+    """
+    Construct a FITS-WCS header for a full-Sun heliographic (Carrington or Stonyhurst) coordinate frame.
+
+    The date-time and observer coordinate of the new coordinate frame
+    are taken from the input map. The resulting WCS covers the full surface
+    of the Sun, and has a reference coordinate at (0, 0) degrees Longitude/Latitude.
+
+    Parameters
+    ----------
+    date :
+        Date for the output header.
+    observer_coordinate :
+        Observer coordinate for the output header.
+    shape : [int, int]
+        Output map shape, number of pixels in (latitude, longitude).
+    frame : {'carrington', 'stonyhurst'}
+        Coordinate frame.
+    projection_code : {'CAR', 'CEA'}
+        Projection to use for the latitude coordinate.
+
+    Returns
+    -------
+    `~sunpy.util.MetaDict`
+
+    See Also
+    --------
+    sunpy.map.header_helper.make_fitswcs_header : A more generic header helper that can be used if more customisation is required.
+
+    Examples
+    --------
+    >>> from sunpy.map.header_helper import make_heliographic_header
+    >>> from sunpy.coordinates import get_earth
+    >>>
+    >>> date = '2020-01-01 12:00:00'
+    >>> observer = get_earth(date)
+    >>> header = make_heliographic_header(date, observer, [90, 180], frame='carrington')
+    >>> header
+    MetaDict([('wcsaxes', 2), ('crpix1', 90.5), ('crpix2', 45.5), ('cdelt1', 2.0), ('cdelt2', 2.0), ('cunit1', 'deg'), ('cunit2', 'deg'), ('ctype1', 'CRLN-CAR'), ('ctype2', 'CRLT-CAR'), ('crval1', 0.0), ('crval2', 0.0), ('lonpole', 0.0), ('latpole', 90.0), ('mjdref', 0.0), ('date-obs', '2020-01-01T12:00:00.000'), ('rsun_ref', 695700000.0), ('dsun_obs', 147096975776.97), ('hgln_obs', 0.0), ('hglt_obs', -3.0011725838606), ('naxis', 2), ('naxis1', 180), ('naxis2', 90), ('pc1_1', 1.0), ('pc1_2', -0.0), ('pc2_1', 0.0), ('pc2_2', 1.0), ('rsun_obs', 975.5398432033492)])
+
+    .. minigallery:: sunpy.map.make_heliographic_header
+    """
+    valid_codes = {"CAR", "CEA"}
+    if projection_code not in valid_codes:
+        raise ValueError(f"projection_code must be one of {valid_codes}")
+
+    valid_frames = {'carrington', 'stonyhurst'}
+    if frame not in valid_frames:
+        raise ValueError(f"frame must be one of {valid_frames}")
+
+    frame_out = SkyCoord(
+        0 * u.deg,
+        0 * u.deg,
+        frame=f"heliographic_{frame}",
+        obstime=date,
+        observer=observer_coordinate,
+        rsun=getattr(observer_coordinate, "rsun", None),
+    )
+
+    if projection_code == "CAR":
+        scale = [360 / int(shape[1]), 180 / int(shape[0])] * u.deg / u.pix
+    elif projection_code == "CEA":
+        # Using the cylindrical equal-area (CEA) projection,
+        # scale needs to be to 180/pi times the sin(latitude) spacing
+        # See Section 5.5, Thompson 2006
+        scale = [
+            360 / int(shape[1]),
+            (180 / np.pi) / (int(shape[0]) / 2)
+        ] * u.deg / u.pix
+
+    header = make_fitswcs_header(shape, frame_out, scale=scale, projection_code=projection_code)
+    return header
