@@ -5,10 +5,10 @@ import pytest
 
 import astropy.units as u
 
-from sunpy.data.test import get_dummy_map_from_header, test_data_filenames
+from sunpy.data.test import get_dummy_map_from_header, get_test_data_filenames
 from sunpy.map.sources.soho import EITMap
 
-header_list = [f for f in test_data_filenames() if 'efz' in f.name and '.header' in f.name]
+header_list = [f for f in get_test_data_filenames() if 'efz' in f.name and '.header' in f.name]
 
 __author__ = "Pritish C. (VaticanCameos)"
 
