@@ -8,6 +8,7 @@ from astropy.wcs import WCS
 import sunpy.map
 from sunpy.coordinates import frames, sun
 from sunpy.map import make_fitswcs_header
+from sunpy.map.header_helper import make_heliographic_header
 from sunpy.util.metadata import MetaDict
 
 
@@ -65,14 +66,7 @@ def test_metakeywords():
     assert isinstance(meta, dict)
 
 
-def test_scale_conversion(map_data, hpc_coord):
-    # The header will have cunit1/2 of arcsec
-    header = make_fitswcs_header(map_data, hpc_coord, scale=[1, 2] * u.arcmin / u.pix)
-    assert header['cdelt1'] == 60
-    assert header['cdelt2'] == 120
-
-
-def test_default_rotation(map_data, hpc_coord):
+def test_deafult_rotation(map_data, hpc_coord):
     header = make_fitswcs_header(map_data, hpc_coord)
     wcs = WCS(header)
     np.testing.assert_allclose(wcs.wcs.pc, [[1, 0], [0, 1]], atol=1e-5)
@@ -85,13 +79,6 @@ def test_rotation_angle(map_data, hpc_coord):
     np.testing.assert_allclose(wcs.wcs.pc, [[0, -1], [1, 0]], atol=1e-5)
 
 
-def test_rotation_angle_rectangular_pixels(map_data, hpc_coord):
-    header = make_fitswcs_header(map_data, hpc_coord, scale=[2, 5] * u.arcsec / u.pix,
-                                 rotation_angle=45*u.deg)
-    wcs = WCS(header)
-    np.testing.assert_allclose(wcs.wcs.pc, np.sqrt(0.5) * np.array([[1, -2.5], [0.4, 1]]), atol=1e-5)
-
-
 def test_rotation_matrix(map_data, hpc_coord):
     header = make_fitswcs_header(map_data, hpc_coord,
                                  rotation_matrix=np.array([[1, 0], [0, 1]]))
@@ -178,14 +165,41 @@ def test_hgs_header(hgs_header, hgs_coord):
 
 
 def test_instrument_keyword(map_data, hpc_coord):
-    header = make_fitswcs_header(map_data, hpc_coord, instrument='test name')
-    assert header['instrume'] == 'test name'
+    instrument_kwargs = {
+        'instrument': 'test name',
+        'observatory': 'test observatory',
+        'telescope': 'test telescope',
+        'wavelength': 171 * u.Angstrom,
+        'exposure': 2 * u.s,
+        'unit': u.Unit('ct s-1'),
+    }
+    header = make_fitswcs_header(map_data, hpc_coord, **instrument_kwargs)
+    assert header['instrume'] == instrument_kwargs['instrument']
+    assert header['obsrvtry'] == instrument_kwargs['observatory']
+    assert header['telescop'] == instrument_kwargs['telescope']
+    assert header['wavelnth'] == instrument_kwargs['wavelength'].to_value()
+    assert header['waveunit'] == instrument_kwargs['wavelength'].unit.to_string("fits")
+    assert header['exptime'] == instrument_kwargs['exposure'].to_value('s')
+    assert header['bunit'] == instrument_kwargs['unit'].to_string("fits")
 
     # Check returned MetaDict will make a `sunpy.map.Map`
     map_test = sunpy.map.Map(map_data, header)
     assert isinstance(map_test, sunpy.map.mapbase.GenericMap)
 
 
+def test_quantity_input(map_data, hpc_coord):
+    # Test that unit information is extracted correctly when data array is a quantity
+    map_unit = u.Unit('ct / s')
+    map_quantity = u.Quantity(map_data, map_unit)
+    header = make_fitswcs_header(map_quantity, hpc_coord)
+    assert header['bunit'] == map_unit.to_string('fits')
+    # In cases where unit is specified and data is a quantity, specified unit will take
+    # precedence
+    override_unit = u.Unit('erg cm-2 s-1')
+    header = make_fitswcs_header(map_quantity, hpc_coord, unit=override_unit)
+    assert header['bunit'] == override_unit.to_string('fits')
+
+
 def test_invalid_inputs(map_data, hcc_coord, hpc_coord_notime, hpc_coord):
     # Raise the HCC error
     with pytest.raises(ValueError):
@@ -212,3 +226,31 @@ def test_invalid_inputs(map_data, hcc_coord, hpc_coord_notime, hpc_coord):
         header = make_fitswcs_header(map_data, hpc_coord, scale=u.Quantity([0, 0]))
     with pytest.raises(u.UnitsError):
         header = make_fitswcs_header(map_data, hpc_coord, scale=u.Quantity([0, 0]*u.arcsec))
+
+
+@pytest.mark.parametrize('frame', ['carrington', 'stonyhurst'])
+# Second case here chosen to produce non-square pixels
+@pytest.mark.parametrize('shape', [[90, 180], [240, 100]])
+@pytest.mark.parametrize('projection_code', ['CAR', 'CEA'])
+def test_make_heliographic_header(aia171_test_map, shape, projection_code, frame):
+    header = make_heliographic_header(aia171_test_map.date, aia171_test_map.observer_coordinate, shape, frame=frame, projection_code=projection_code)
+    carr_map = aia171_test_map.reproject_to(header)
+
+    # Check upper right and lower left coordinates are as expected
+    ll_coord = carr_map.pixel_to_world(-0.5 * u.pix, -0.5 * u.pix)
+    assert ll_coord.lon in [-180 * u.deg, 180*u.deg]
+    assert ll_coord.lat == -90 * u.deg
+    assert ll_coord.frame.name == f"heliographic_{frame}"
+
+    ur_coord = carr_map.pixel_to_world((shape[1] - 0.5) * u.pix, (shape[0] - 0.5) * u.pix)
+    assert ur_coord.lon in [-180 * u.deg, 180*u.deg]
+    assert ur_coord.lat == 90 * u.deg
+    assert ur_coord.frame.name == f"heliographic_{frame}"
+
+
+def test_make_heliographic_header_invalid_inputs(aia171_test_map):
+    with pytest.raises(ValueError, match='projection_code must be one of'):
+        make_heliographic_header(aia171_test_map.date, aia171_test_map.observer_coordinate, [90, 180], frame='carrington', projection_code='blah')
+
+    with pytest.raises(ValueError, match='frame must be one of'):
+        make_heliographic_header(aia171_test_map.date, aia171_test_map.observer_coordinate, [90, 180], frame='blah')
