@@ -6,12 +6,11 @@ from collections import OrderedDict
 
 import numpy as np
 import pandas as pd
-from matplotlib import pyplot as plt
 
 import astropy.units as u
 
-from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
+from sunpy.util.decorators import deprecate_positional_args_since
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
 
@@ -54,10 +53,12 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
     * `NOAA plots of Solar Cycle Progression <https://www.swpc.noaa.gov/products/solar-cycle-progression>`_
     * `NOAA Product List <https://www.swpc.noaa.gov/products-and-data>`_
     """
-    # Class attribute used to specify the source class of the TimeSeries.
+    # Class attributes used to specify the source class of the TimeSeries
+    # and a URL to the mission website.
     _source = 'noaaindices'
+    _url = "https://www.swpc.noaa.gov/products-and-data"
 
-    def plot(self, axes=None, plot_type='sunspot SWO', **kwargs):
+    def plot(self, axes=None, plot_type='sunspot SWO', columns=None, **kwargs):
         """
         Plots NOAA Indices.
 
@@ -67,6 +68,8 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
             The axes on which to plot the TimeSeries.
         plot_type : {``"sunspot SWO"``, ``"sunspot RI"``, ``"sunspot compare"``, ``"radio"``, ``"geo"``}, optional
             The type of plot required. Defaults to ``"sunspot SWO"``.
+        columns : list[str], optional
+            Unused, but there to maintain uniformity among plot methods.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
             functions.
@@ -76,9 +79,7 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         `~matplotlib.axes.Axes`
             The plot axes.
         """
-        self._validate_data_for_plotting()
-        if axes is None:
-            axes = plt.gca()
+        axes, columns = self._setup_axes_columns(axes, columns)
 
         if plot_type == 'sunspot SWO':
             to_plot = ['sunspot SWO', 'sunspot SWO smooth']
@@ -101,15 +102,17 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         to_plot = self.to_dataframe()[to_plot]
         to_plot.plot(ax=axes, **kwargs)
 
+        axes.set_xlim(min(to_plot.dropna(how='all').index),
+                      max(to_plot.dropna(how='all').index))
         axes.set_ylim(0)
         axes.set_ylabel(ylabel)
-        axes.yaxis.grid(True, 'major')
-        axes.xaxis.grid(True, 'major')
         axes.legend()
+        self._setup_x_axis(axes)
         return axes
 
     @peek_show
-    def peek(self, title="Solar Cycle Progression", plot_type='sunspot SWO', **kwargs):
+    @deprecate_positional_args_since("4.1")
+    def peek(self, *, title="Solar Cycle Progression", plot_type='sunspot SWO', columns=None, **kwargs):
         """
         Displays the NOAA Indices as a function of time by calling
         `~sunpy.timeseries.sources.noaa.NOAAPredictIndicesTimeSeries.plot`.
@@ -127,6 +130,8 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
             The title of the plot. Defaults to "Solar Cycle Progression".
         plot_type : {``"sunspot SWO"``, ``"sunspot RI"``, ``"sunspot compare"``, ``"radio"``, ``"geo"``}, optional
             The type of plot required. Defaults to ``"sunspot SWO"``.
+        columns : list[str], optional
+            Unused, but there to maintain uniformity among peek methods.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
             functions.
@@ -169,8 +174,6 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         # Convoluted time index handling
         data = data.set_index('time-tag')
         data.index = pd.DatetimeIndex(data.index.values)
-        data.index = pd.DatetimeIndex(parse_time(
-            [x for x in data.index.values]).isot.astype('datetime64'))
 
         # Add the units data, reported in radio flux values (sfu) originally.
         units = OrderedDict([('sunspot RI', u.dimensionless_unscaled),
@@ -224,10 +227,14 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
     * `NOAA Product List <https://www.swpc.noaa.gov/products-and-data>`_
     """
 
-    # Class attribute used to specify the source class of the TimeSeries.
+    # Class attributes used to specify the source class of the TimeSeries
+    # and a URL to the mission website.
     _source = 'noaapredictindices'
+    _url = "https://www.swpc.noaa.gov/products-and-data"
 
-    def plot(self, axes=None, **plot_args):
+    _peek_title = "Solar Cycle Sunspot Number Prediction"
+
+    def plot(self, axes=None, columns=None, **plot_args):
         """
         Plots predicted NOAA Indices as a function of time from a pandas dataframe.
 
@@ -235,6 +242,8 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         ----------
         axes : `matplotlib.axes.Axes`, optional
             The axes on which to plot the TimeSeries.
+        columns : list[str], optional
+            Unused, but there to maintain uniformity among plot methods.
         **kwargs : `dict`
             Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
             functions.
@@ -244,10 +253,9 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         `~matplotlib.axes.Axes`
             The plot axes.
         """
-        self._validate_data_for_plotting()
+        axes, columns = self._setup_axes_columns(axes, columns)
+
         dataframe = self.to_dataframe()
-        if axes is None:
-            axes = plt.gca()
         dataframe['sunspot'].plot(color='b', **plot_args)
         dataframe['sunspot high'].plot(linestyle='--', color='b', **plot_args)
         dataframe['sunspot low'].plot(linestyle='--', color='b', **plot_args)
@@ -256,34 +264,9 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         axes.yaxis.grid(True, 'major')
         axes.xaxis.grid(True, 'major')
         axes.legend()
+        self._setup_x_axis(axes)
         return axes
 
-    @peek_show
-    def peek(self, title="Solar Cycle Sunspot Number Prediction", **plot_args):
-        """
-        Displays the predicted NOAA Indices as a function of time by calling
-        `~sunpy.timeseries.sources.noaa.NOAAPredictIndicesTimeSeries.plot`.
-
-        .. plot::
-
-            import sunpy.timeseries
-            noaa_url = 'https://services.swpc.noaa.gov/json/solar-cycle/predicted-solar-cycle.json'
-            noaa = sunpy.timeseries.TimeSeries(noaa_url, source='NOAAPredictIndices')
-            noaa.peek()
-
-        Parameters
-        ----------
-        title : `str`, optional
-            The title of the plot. Defaults to "Solar Cycle Sunspot Number Prediction".
-        **plot_args : `dict`
-            Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
-            functions.
-        """
-        axes = self.plot(**plot_args)
-        axes.set_title(title)
-        fig = plt.gcf()
-        return fig
-
     @classmethod
     def _parse_file(cls, filepath):
         suffix = Path(filepath).suffix
@@ -326,8 +309,6 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         # Convoluted time index handling
         data = data.set_index('time-tag')
         data.index = pd.DatetimeIndex(data.index.values)
-        data.index = pd.DatetimeIndex(parse_time(
-            [x for x in data.index.values]).isot.astype('datetime64'))
         # Add the units data, reported in radio flux values (sfu) originally.
         units = OrderedDict([('sunspot', u.dimensionless_unscaled),
                              ('sunspot high', u.dimensionless_unscaled),
